@@ -1,7 +1,7 @@
 package Perinci::Access::Lite;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -162,8 +162,8 @@ sub request {
     } elsif ($url =~ m!\Ahttps?:/(/?)!i) {
         my $is_unix = !$1;
         my $ht;
-        require JSON::MaybeXS;
-        state $json = JSON::MaybeXS->new->allow_nonref;
+        require JSON;
+        state $json = JSON->new->allow_nonref;
         if ($is_unix) {
             require HTTP::Tiny::UNIX;
             $ht = HTTP::Tiny::UNIX->new;
@@ -216,7 +216,7 @@ Perinci::Access::Lite - A lightweight Riap client library
 
 =head1 VERSION
 
-This document describes version 0.13 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2016-03-16.
+This document describes version 0.14 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2016-09-25.
 
 =head1 DESCRIPTION
 
